@@ -643,7 +643,7 @@ def init_csync2_remote():
         if not re.search(r"^\s*host.*\s+%s\s*;" % (newhost), curr_cfg, flags=re.M):
             curr_cfg = re.sub(r"\bhost.*\s+\S+\s*;", r"\g<0>\n\thost %s;" % (utils.doublequote(newhost)), curr_cfg, count=1)
             utils.str2file(curr_cfg, CSYNC2_CFG)
-            invoke("csync2", "-c", CSYNC2_CFG)
+            csync2_update("/")
         else:
             log(": Not updating %s - remote host %s already exists" % (CSYNC2_CFG, newhost))
     finally:
@@ -739,6 +739,8 @@ def init_corosync():
     Configure corosync (unicast or multicast, encrypted?)
     """
     def check_amazon():
+        if not utils.is_program("dmidecode"):
+            return False
         _rc, outp = utils.get_stdout("dmidecode -s system-version")
         return re.search(r"\<.*\.amazon\>", outp) is not None
 
@@ -980,6 +982,9 @@ Configure SBD:
                     csync2_update(SYSCONFIG_SBD)
             return
 
+        if utils.is_program("sbd") is None:
+            error("sbd executable not found! Cannot configure SBD.")
+
         dev = ""
         dev_looks_sane = False
         while not dev_looks_sane:
@@ -1009,7 +1014,12 @@ Configure SBD:
         error("Failed to initialize SBD device %s" % (_context.sbd_device))
     status_done()
 
-    utils.sysconfig_set(SYSCONFIG_SBD, SBD_DEVICE=_context.sbd_device, SBD_WATCHDOG="yes")
+    utils.sysconfig_set(SYSCONFIG_SBD,
+                        SBD_DEVICE=_context.sbd_device,
+                        SBD_PACEMAKER="yes",
+                        SBD_STARTMODE="always",
+                        SBD_DELAY_START="no",
+                        SBD_WATCHDOG_DEV=detect_watchdog_device())
     csync2_update(SYSCONFIG_SBD)
 
 
@@ -1271,7 +1281,7 @@ def join_cluster(seed_host):
     # that yet, so the following crawling horror takes a punt on the seed
     # node being up, then asks it for a list of mountpoints...
     if _context.cluster_node:
-        rc, outp = utils.get_stdout("ssh -o StrictHostKeyChecking=no root@{} 'cibadmin -Q --xpath \"//primitive\"'".format(seed_host))
+        rc, outp, _ = utils.get_stdout_stderr("ssh -o StrictHostKeyChecking=no root@{} 'cibadmin -Q --xpath \"//primitive\"'".format(seed_host))
         if len(outp):
             xml = etree.fromstring(outp)
             mountpoints = xml.xpath(' and '.join(['//primitive[@class="ocf"',
@@ -1294,6 +1304,7 @@ def join_cluster(seed_host):
     is_unicast = "nodelist" in open(corosync.conf()).read()
     if is_unicast:
         corosync.add_node(utils.this_node())
+        csync2_update(corosync.conf())
 
     # if no SBD devices are configured,
     # check the existing cluster if the sbd service is enabled
@@ -1306,16 +1317,29 @@ def join_cluster(seed_host):
     # attempt to join the cluster failed)
     init_cluster_local()
 
+    # apply nodelist in cluster
+    if is_unicast:
+        invoke("crm cluster run 'crm corosync reload'")
+
     def update_expected_votes():
         # get a list of nodes, excluding remote nodes
         nodelist = None
-        rc, nodelist_text = utils.get_stdout("cibadmin -Ql --xpath '/cib/status/node_state'")
-        if rc == 0:
-            try:
-                nodelist_xml = etree.fromstring(nodelist_text)
-                nodelist = [n.get('uname') for n in nodelist_xml.xpath('//node_state') if n.get('remote_node') != 'true']
-            except Exception:
-                pass
+        loop_count = 0
+        while True:
+            rc, nodelist_text = utils.get_stdout("cibadmin -Ql --xpath '/cib/status/node_state'")
+            if rc == 0:
+                try:
+                    nodelist_xml = etree.fromstring(nodelist_text)
+                    nodelist = [n.get('uname') for n in nodelist_xml.xpath('//node_state') if n.get('remote_node') != 'true']
+                    if len(nodelist) >= 2:
+                        break
+                except Exception:
+                    break
+            # timeout: 10 seconds
+            if loop_count == 10:
+                break
+            loop_count += 1
+            sleep(1)
 
         # Increase expected_votes
         # TODO: wait to adjust expected_votes until after cluster join,
@@ -1656,7 +1680,7 @@ def bootstrap_remove(cluster_node=None, quiet=False, yes_to_all=False, force=Fal
         else:
             # stop cluster
             if not stop_service("corosync"):
-                error("Stopping corosync on failed")
+                error("Stopping corosync failed")
 
             # remove all trace of cluster from this node
             # delete configuration files from the node to be removed
