@@ -62,10 +62,11 @@ class Cluster(command.UI):
         '''
         Starts the cluster services on this node
         '''
-        rc, out, err = utils.get_stdout_stderr('service pacemaker start')
-        if rc != 0:
-            context.fatal_error("Failed to start pacemaker service: %s" % (err))
-        err_buf.info("Cluster services started")
+        try:
+            utils.start_service("pacemaker")
+            err_buf.info("Cluster services started")
+        except IOError as err:
+            context.fatal_error(str(err))
 
         # TODO: optionally start services on all nodes or specific node
 
@@ -74,10 +75,11 @@ class Cluster(command.UI):
         '''
         Stops the cluster services on this node
         '''
-        rc, out, err = utils.get_stdout_stderr('service pacemaker stop')
-        if rc != 0:
-            context.fatal_error("Failed to stop pacemaker service: %s" % (err))
-        err_buf.info("Cluster services stopped")
+        try:
+            utils.stop_service("corosync")
+            err_buf.info("Cluster services stopped")
+        except IOError as err:
+            context.fatal_error(str(err))
 
         # TODO: optionally stop services on all nodes or specific node
 
