@@ -72,10 +72,13 @@ def network_defaults(interface=None):
         sp = l.split()
         if info[0] is None and len(sp) >= 5 and sp[0] == 'default' and sp[1] == 'via':
             info[0] = sp[4]
-        if info[0] is not None:
-            if sp[0].find('/') >= 0 and valfor(sp, 'dev') == info[0]:
+        if info[0] is not None and valfor(sp, 'dev') == info[0] and sp[0] != 'default':
+            if sp[0].find('/') >= 0:
                 nw, length = sp[0].split('/')
                 info[1], info[2], info[3] = valfor(sp, 'src'), nw, length
+            # we are reading /32 route entry
+            else:
+                info[1], info[2], info[3] = valfor(sp, 'src'), sp[0], 32
     if info[0] is None:
         raise ValueError("Failed to determine default network interface")
     return tuple(info)
@@ -116,6 +119,66 @@ def is_program(prog):
     return None
 
 
+def pacemaker_20_daemon(new, old):
+    "helper to discover renamed pacemaker daemons"
+    if is_program(new):
+        return new
+    return old
+
+
+@memoize
+def pacemaker_attrd():
+    return pacemaker_20_daemon("pacemaker-attrd", "attrd")
+
+
+@memoize
+def pacemaker_based():
+    return pacemaker_20_daemon("pacemaker-based", "cib")
+
+
+@memoize
+def pacemaker_controld():
+    return pacemaker_20_daemon("pacemaker-controld", "crmd")
+
+
+@memoize
+def pacemaker_execd():
+    return pacemaker_20_daemon("pacemaker-execd", "lrmd")
+
+
+@memoize
+def pacemaker_fenced():
+    return pacemaker_20_daemon("pacemaker-fenced", "stonithd")
+
+
+@memoize
+def pacemaker_remoted():
+    return pacemaker_20_daemon("pacemaker-remoted", "pacemaker_remoted")
+
+
+@memoize
+def pacemaker_schedulerd():
+    return pacemaker_20_daemon("pacemaker-schedulerd", "pengine")
+
+
+def pacemaker_daemon(name):
+    if name == "attrd" or name == "pacemaker-attrd":
+        return pacemaker_attrd()
+    if name == "cib" or name == "pacemaker-based":
+        return pacemaker_based()
+    if name == "crmd" or name == "pacemaker-controld":
+        return pacemaker_controld()
+    if name == "lrmd" or name == "pacemaker-execd":
+        return pacemaker_execd()
+    if name == "stonithd" or name == "pacemaker-fenced":
+        return pacemaker_fenced()
+    if name == "pacemaker_remoted" or name == "pacemeaker-remoted":
+        return pacemaker_remoted()
+    if name == "pengine" or name == "pacemaker-schedulerd":
+        return pacemaker_schedulerd()
+    raise ValueError("Not a Pacemaker daemon name: {}".format(name))
+
+
 def can_ask():
     """
     Is user-interactivity possible?
@@ -967,7 +1030,7 @@ def is_process(s):
             procname = basename(cmdline.replace('\x00', ' ').split(' ')[0])
             if procname == s:
                 return True
-        except os.error:
+        except EnvironmentError:
             # a process may have died since we got the list of pids
             pass
     return False
@@ -1344,7 +1407,7 @@ def load_graphviz_file(ini_f):
 def get_pcmk_version(dflt):
     version = dflt
 
-    crmd = is_program('crmd')
+    crmd = pacemaker_controld()
     if crmd:
         cmd = crmd
     else:
@@ -1620,6 +1683,45 @@ def service_info(name):
     return None
 
 
+def start_service(service, enable=False, start=True):
+    """
+    Start (and optionally enable) systemd service
+    TODO: support other init systems
+    """
+    if enable:
+        _rc, _out, _err = get_stdout_stderr("systemctl -q enable {}".format(service))
+    if start:
+        rc, _out, _err = get_stdout_stderr("systemctl -q is-active {}".format(service))
+        if rc != 0:
+            rc, _out, err = get_stdout_stderr("systemctl -q start {}".format(service))
+            if rc != 0:
+                raise IOError("systemd failed to start {}: {}".format(service, err))
+
+
+def stop_service(service, disable=False, stop=True):
+    """
+    Stop (and optionally disable) systemd service
+    TODO: support other init systems
+    """
+    rc, err = 0, ""
+    if stop:
+        rc, _out, err = get_stdout_stderr("systemctl -q stop {}".format(service))
+    if disable:
+        _rc, _out, _err = get_stdout_stderr("systemctl -q disable {}".format(service))
+    if rc != 0:
+        raise IOError("systemd failed to stop {}: {}".format(service, err))
+
+
+def enable_service(service, start=False):
+    "Enable (and optionally start) system service"
+    start_service(service, enable=True, start=start)
+
+
+def disable_service(service, stop=False):
+    "Enable (and optionally stop) system service"
+    stop_service(service, disable=True, stop=stop)
+
+
 def running_on(resource):
     "returns list of node names where the given resource is running"
     rsc_locate = "crm_resource --resource '%s' --locate"
